==> openshift-model-operatorhub-5.11.2-sources.jar: io/fabric8/openshift/api/model/operatorhub/v1alpha1/IconFluentImpl.java <==
package io.fabric8.openshift.api.model.operatorhub.v1alpha1;

import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public class IconFluentImpl<A extends io.fabric8.openshift.api.model.operatorhub.v1alpha1.IconFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.operatorhub.v1alpha1.IconFluent<A>{
  public IconFluentImpl() {
  }
  public IconFluentImpl(io.fabric8.openshift.api.model.operatorhub.v1alpha1.Icon instance) {
    this.withBase64data(instance.getBase64data()); 
    this.withMediatype(instance.getMediatype()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String base64data;
  private java.lang.String mediatype;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getBase64data() {
    return this.base64data;
  }
  public A withBase64data(java.lang.String base64data) {
    this.base64data=base64data; return (A) this;
  }
  public java.lang.Boolean hasBase64data() {
    return this.base64data != null;
  }
  
  /**
   * Method is deprecated. use withBase64data instead.
   */
  @java.lang.Deprecated
  public A withNewBase64data(java.lang.String arg0) {
    return (A)withBase64data(new String(arg0));
  }
  public java.lang.String getMediatype() {
    return this.mediatype;
  }
  public A withMediatype(java.lang.String mediatype) {
    this.mediatype=mediatype; return (A) this;
  }
  public java.lang.Boolean hasMediatype() {
    return this.mediatype != null;
  }
  
  /**
   * Method is deprecated. use withMediatype instead.
   */
  @java.lang.Deprecated
  public A withNewMediatype(java.lang.String arg0) {
    return (A)withMediatype(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    IconFluentImpl that = (IconFluentImpl) o;
    if (base64data != null ? !base64data.equals(that.base64data) :that.base64data != null) return false;
    if (mediatype != null ? !mediatype.equals(that.mediatype) :that.mediatype != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(base64data,  mediatype,  additionalProperties,  super.hashCode());
  }
  
}

==> openshift-model-operatorhub-5.12.1-sources.jar: io/fabric8/openshift/api/model/operatorhub/v1alpha1/IconFluentImpl.java <==
package io.fabric8.openshift.api.model.operatorhub.v1alpha1;

import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public class IconFluentImpl<A extends io.fabric8.openshift.api.model.operatorhub.v1alpha1.IconFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.operatorhub.v1alpha1.IconFluent<A>{
  public IconFluentImpl() {
  }
  public IconFluentImpl(io.fabric8.openshift.api.model.operatorhub.v1alpha1.Icon instance) {
    this.withBase64data(instance.getBase64data()); 
    this.withMediatype(instance.getMediatype()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String base64data;
  private java.lang.String mediatype;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getBase64data() {
    return this.base64data;
  }
  public A withBase64data(java.lang.String base64data) {
    this.base64data=base64data; return (A) this;
  }
  public java.lang.Boolean hasBase64data() {
    return this.base64data != null;
  }
  
  /**
   * Method is deprecated. use withBase64data instead.
   */
  @java.lang.Deprecated
  public A withNewBase64data(java.lang.String arg0) {
    return (A)withBase64data(new String(arg0));
  }
  public java.lang.String getMediatype() {
    return this.mediatype;
  }
  public A withMediatype(java.lang.String mediatype) {
    this.mediatype=mediatype; return (A) this;
  }
  public java.lang.Boolean hasMediatype() {
    return this.mediatype != null;
  }
  
  /**
   * Method is deprecated. use withMediatype instead.
   */
  @java.lang.Deprecated
  public A withNewMediatype(java.lang.String arg0) {
    return (A)withMediatype(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    IconFluentImpl that = (IconFluentImpl) o;
    if (base64data != null ? !base64data.equals(that.base64data) :that.base64data != null) return false;
    if (mediatype != null ? !mediatype.equals(that.mediatype) :that.mediatype != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(base64data,  mediatype,  additionalProperties,  super.hashCode());
  }
  
}
